@@ -22,13 +22,11 @@
 
 K_PLUGIN_CLASS_WITH_JSON(KateSessions, "plasma-runner-katesessions.json")
 
-KateSessions::KateSessions(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
-    : AbstractRunner(parent, metaData, args)
+KateSessions::KateSessions(QObject *parent, const KPluginMetaData &metaData)
+    : AbstractRunner(parent, metaData)
 {
-    setObjectName(QStringLiteral("Kate Sessions"));
-
-    addSyntax(RunnerSyntax(QStringLiteral("kate :q:"), i18n("Finds Kate sessions matching :q:.")));
-    addSyntax(RunnerSyntax(QStringLiteral("kate"), i18n("Lists all the Kate editor sessions in your account.")));
+    addSyntax(QStringLiteral("kate :q:"), i18n("Finds Kate sessions matching :q:."));
+    addSyntax(QStringLiteral("kate"), i18n("Lists all the Kate editor sessions in your account."));
 
     // Initialize watchers and sessions
     setTriggerWords({m_triggerWord});
@@ -41,9 +39,10 @@ void KateSessions::match(RunnerContext &context)
     if (term.trimmed().compare(m_triggerWord, Qt::CaseInsensitive) == 0) {
         listAll = true;
         term.clear();
-    } else if (term.at(4) == QLatin1Char(' ')) {
-        term = term.remove(m_triggerWord, Qt::CaseInsensitive).trimmed();
-    } else {
+    } else if (term.startsWith(m_triggerWord + ' ')) {
+        term.remove(m_triggerWord, Qt::CaseInsensitive);
+        term = std::move(term).trimmed();
+    } else if (!context.singleRunnerQueryMode()) {
         // Prevent results for queries like "katee"
         return;
     }
@@ -57,7 +56,7 @@ void KateSessions::match(RunnerContext &context)
         QString session = m_model->index(i).data(ProfilesModel::NameRole).toString();
         if (listAll || session.compare(term, Qt::CaseInsensitive) == 0) {
             QueryMatch match(this);
-            match.setType(QueryMatch::ExactMatch);
+            match.setCategoryRelevance(QueryMatch::CategoryRelevance::Highest);
             match.setRelevance(session.compare(term, Qt::CaseInsensitive) == 0 ? 1 : 0.8);
             match.setIconName(m_triggerWord);
             match.setData(session);
@@ -89,10 +88,8 @@ void KateSessions::match(RunnerContext &context)
     context.addMatches(matches);
 }
 
-void KateSessions::run(const RunnerContext &context, const QueryMatch &match)
+void KateSessions::run(const RunnerContext & /*context*/, const QueryMatch &match)
 {
-    Q_UNUSED(context)
-
     m_model->openProfile(match.data().toString());
 }
 
