@@ -17,16 +17,12 @@
 #include <QFileInfo>
 #include <QStandardPaths>
 
-KonsoleProfiles::KonsoleProfiles(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
-    : AbstractRunner(parent, metaData, args)
+KonsoleProfiles::KonsoleProfiles(QObject *parent, const KPluginMetaData &metaData)
+    : AbstractRunner(parent, metaData)
 {
-    setObjectName(QStringLiteral("Konsole Profiles"));
-
-    RunnerSyntax s(QStringLiteral(":q:"), i18n("Finds Konsole profiles matching :q:."));
-    s.addExampleQuery(QStringLiteral("konsole :q:"));
-    addSyntax(s);
-    addSyntax(RunnerSyntax(QStringLiteral("konsole"), i18n("Lists all the Konsole profiles in your account.")));
-    setMinLetterCount(3);
+    addSyntax({QStringLiteral(":q:"), QStringLiteral("konsole :q:")}, i18n("Finds Konsole profiles matching :q:."));
+    addSyntax(QStringLiteral("konsole"), i18n("Lists all the Konsole profiles in your account."));
+    setTriggerWords({m_triggerWord});
 }
 
 void KonsoleProfiles::match(RunnerContext &context)
@@ -39,7 +35,7 @@ void KonsoleProfiles::match(RunnerContext &context)
         if (name.contains(term, Qt::CaseInsensitive)) {
             const QString profileIdentifier = idx.data(ProfilesModel::ProfileIdentifierRole).toString();
             QueryMatch match(this);
-            match.setType(QueryMatch::PossibleMatch);
+            match.setCategoryRelevance(QueryMatch::CategoryRelevance::Low);
             match.setIconName(idx.data(ProfilesModel::IconNameRole).toString());
             match.setData(profileIdentifier);
             match.setText(QStringLiteral("Konsole: ") + name);
@@ -49,9 +45,8 @@ void KonsoleProfiles::match(RunnerContext &context)
     }
 }
 
-void KonsoleProfiles::run(const RunnerContext &context, const QueryMatch &match)
+void KonsoleProfiles::run(const RunnerContext & /*context*/, const QueryMatch &match)
 {
-    Q_UNUSED(context)
     const QString profile = match.data().toString();
     m_model->openProfile(profile);
 }
